@@ -1,14 +1,18 @@
 ###############################################################################
 ## Implementation of minimum distance estimation
 ###############################################################################
-MDEstimator <- function(x, ParamFamily, distance = KolmogorovDist, dist.name, 
+MDEstimator <- function(x, ParamFamily, distance = KolmogorovDist,
+                        dist.name,  paramDepDist = FALSE,
                         startPar = NULL,  Infos, 
-                        trafo = NULL, penalty = 0, asvar.fct, ...){
+                        trafo = NULL, penalty = 1e20, asvar.fct, na.rm = TRUE,
+                        ...){
 
     ## preparation: getting the matched call
     es.call <- match.call()
     dots <- match.call(expand.dots = FALSE)$"..."
 
+    completecases <- complete.cases(x)
+    if(na.rm) x <- na.omit(x)
 
     ## some checking
     if(!is.numeric(x))
@@ -17,20 +21,17 @@ MDEstimator <- function(x, ParamFamily, distance = KolmogorovDist, dist.name,
     if(missing(dist.name))
       dist.name <- names(distance(x, ParamFamily@distribution))
 
-
+    if(paramDepDist) dots$thetaPar <-NULL
 
     ## manipulation of the arg list to method mceCalc
-    argList <- c(list(x = x, PFam = ParamFamily, criterion = distance, 
+    argList <- c(list(x = x, PFam = ParamFamily, criterion = distance,
                    startPar = startPar, penalty = penalty, 
-                   crit.name = dist.name))
+                   crit.name = dist.name, withthetaPar = paramDepDist))
     if(missing(Infos))      Infos <- NULL
     argList <- c(argList, Infos = Infos)
     if(!is.null(dots))      argList <- c(argList, dots)
-
-
     ## call to mceCalc
     res0 <- do.call(mceCalc, argList)
-
     ## digesting the results of mceCalc
     names(res0$criterion) <- dist.name
 
@@ -46,6 +47,7 @@ MDEstimator <- function(x, ParamFamily, distance = KolmogorovDist, dist.name,
     ## digesting the results of mceCalc
     res <- do.call(.process.meCalcRes, argList)
 
+    res@completecases <- completecases
     return(res)
 }
 
